#
# spec file for package rustscan
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2020, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rustscan
Version:        1.8.0
Release:        1.5
Summary:        Fast network port scanner
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/RustScan/RustScan
Source:         https://github.com/RustScan/RustScan/archive/%{version}.tar.gz#/RustScan-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  cargo
BuildRequires:  rust
Requires:       nmap

%description
Find all open ports fast with RustScan, then automatically
pipe them into Nmap.

%prep
%setup -qa1 -n RustScan-%{version}
mkdir .cargo
cat >.cargo/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
cargo build --release --locked %{?_smp_mflags}

%install
cargo install --no-track --root=%{buildroot}%{_prefix} --path .

%files
%license LICENSE
%doc README.md
%{_bindir}/rustscan

%changelog
* Fri Aug 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8.0
  Features
  * Allow randomised order for manual ports.
  * Add --port and --range options.
  * Added host resolution.
  * Added accessible mode.
  * Added port scanning strategy.
  Maintenance
  * Added the Git submodule for RustScan Scripting Engine
  * Removed -A from Nmap.
  * Added top 1k ports in config file.
  * Excluded unnecessary files.
  Fixed bugs
  * GH#169, GH#165, GH#163, GH#153
* Sun Aug  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7.1
  Features
  * New terminal user interface. Much prettier and easier to read
  * Port randomisation (so it's not a sequential hit of multiple
    ports)
  Maintenance
  * Created macros to easily report information back to the user
  * Reduced size of error messages (boy were they long smirk_cat )
  * More tests
- Update to version 1.6.0
  * Added multiple IP support. This is in extremely early stage,
    but it works.
  Maintenance
  * Fixed help menu bugs and quiet mode not working bugs.
* Tue Aug  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.2
  * Added --appdirs flag to find the appdirs location.
  * Refactored batch size to fix #58.
  * Fixed bug where appdirs wasn't pointing to the complete
    directory.
  * Fixed bug where automatic ulimit lowering wasn't working on
    systems with extremely low ulimits (< 250).
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.4.0
